@@ -14,13 +14,13 @@ from fencing import *
 #BEGIN_VERSION_GENERATION
 RELEASE_VERSION="New RSA2 Agent - test release on steroids"
 REDHAT_COPYRIGHT=""
-BUILD_DATE="March, 2009"
+BUILD_DATE=""
 #END_VERSION_GENERATION
 
 def get_power_status(conn, options):
 	try:
 		conn.send("power state\r\n")
-		conn.log_expect(options, options["-c"], SHELL_TIMEOUT)
+		conn.log_expect(options, options["-c"], int(options["-Y"]))
 	except pexpect.EOF:
 		fail(EC_CONNECTION_LOST)
 	except pexpect.TIMEOUT:
@@ -32,7 +32,7 @@ def get_power_status(conn, options):
 def set_power_status(conn, options):
 	try:
 		conn.send("power " + options["-o"] + "\r\n")
-		conn.log_expect(options, options["-c"], POWER_TIMEOUT)
+		conn.log_expect(options, options["-c"], int(options["-g"]))
 	except pexpect.EOF:
 		fail(EC_CONNECTION_LOST)
 	except pexpect.TIMEOUT:
@@ -41,10 +41,12 @@ def set_power_status(conn, options):
 def main():
 	device_opt = [  "help", "version", "agent", "quiet", "verbose", "debug",
 			"action", "ipaddr", "login", "passwd", "passwd_script",
-			"cmd_prompt", "secure", "ipport" ]
+			"cmd_prompt", "secure", "identity_file", "ipport",
+			"power_timeout", "shell_timeout", "login_timeout", "power_wait" ]
 
 	atexit.register(atexit_handler)
 
+	all_opt["login_timeout"]["default"] = 10
 	options = check_input(device_opt, process_input(device_opt))
 
 	## 
@@ -56,13 +58,21 @@ def main():
 	# This device will not allow us to login even with LANG=C
 	options["ssh_options"] = "-F /dev/null"
 
-	show_docs(options)
+	docs = { }
+	docs["shortdesc"] = "Fence agent for IBM RSA"
+	docs["longdesc"] = "fence_rsa is an I/O Fencing agent \
+which can be used with the IBM RSA II management interface. It \
+logs into an RSA II device via telnet and reboots the associated \
+machine. Lengthy telnet connections to the RSA II device should \
+be avoided while a GFS cluster is running because the connection \
+will block any necessary fencing actions."
+	show_docs(options, docs)
 	
 	##
 	## Operate the fencing device
 	######
 	conn = fence_login(options)
-	fence_action(conn, options, set_power_status, get_power_status, None)
+	result = fence_action(conn, options, set_power_status, get_power_status, None)
 
 	##
 	## Logout from system
@@ -73,7 +83,9 @@ def main():
 	except exceptions.OSError:
 		pass
 	except pexpect.ExceptionPexpect:
-		pass	
+		pass
+	
+	sys.exit(result)
 
 if __name__ == "__main__":
 	main()
